==> haskell-deepseq-generics-0.2.0.0-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-deepseq-generics.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: deepseq-generics
version: 0.2.0.0
id: deepseq-generics-0.2.0.0-1vEsN63mezSGRpRYvUTdz8
key: deepseq-generics-0.2.0.0-1vEsN63mezSGRpRYvUTdz8
license: BSD-3-Clause
copyright: 2012, Herbert Valerio Riedel
maintainer: hvr@gnu.org
author: Herbert Valerio Riedel
homepage: https://github.com/hvr/deepseq-generics
synopsis: GHC.Generics-based Control.DeepSeq.rnf implementation
description:
    This package provides a "GHC.Generics"-based
    '\''Control.DeepSeq.Generics.genericRnf'\'' function which can be used
    for providing a '\''rnf'\'' implementation. See the documentation for
    the '\''genericRnf'\'' function in the "Control.DeepSeq.Generics" module
    to get started.
    .
    The original idea was pioneered in the @generic-deepseq@ package
    (see <http://www.haskell.org/pipermail/haskell-cafe/2012-February/099551.html>
    for more information).
    .
    This package differs from the @generic-deepseq@ package by working
    in combination with the existing @deepseq@ package as opposed to
    defining a conflicting drop-in replacement for @deepseq@'\''s
    @Control.DeepSeq@ module.
    .
    __Note__: The ability to auto-derive via "GHC.Generics" has been
    merged into @deepseq-1.4.0.0@. This package is now still useful
    for writing code that'\''s also compatible with older @deepseq@
    versions not yet providing "GHC.Generics"-support.
category: Control
abi: 725a8f8c0f9e81d5fa62bf6e24561fcc
exposed: True
exposed-modules:
    Control.DeepSeq.Generics
import-dirs: /usr/lib/ghc-8.4.3/site-local/deepseq-generics-0.2.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/deepseq-generics-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/deepseq-generics-0.2.0.0
hs-libraries: HSdeepseq-generics-0.2.0.0-1vEsN63mezSGRpRYvUTdz8
depends:
    base-4.11.1.0 ghc-prim-0.5.2.0 deepseq-1.4.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-deepseq-generics/html/deepseq-generics.haddock
haddock-html: /usr/share/doc/haskell-deepseq-generics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-deepseq-generics-0.2.0.0-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-deepseq-generics.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: deepseq-generics
version: 0.2.0.0
id: deepseq-generics-0.2.0.0-JZY7BpT2g3X1HaqlHiVnph
key: deepseq-generics-0.2.0.0-JZY7BpT2g3X1HaqlHiVnph
license: BSD-3-Clause
copyright: 2012, Herbert Valerio Riedel
maintainer: hvr@gnu.org
author: Herbert Valerio Riedel
homepage: https://github.com/hvr/deepseq-generics
synopsis: GHC.Generics-based Control.DeepSeq.rnf implementation
description:
    This package provides a "GHC.Generics"-based
    '\''Control.DeepSeq.Generics.genericRnf'\'' function which can be used
    for providing a '\''rnf'\'' implementation. See the documentation for
    the '\''genericRnf'\'' function in the "Control.DeepSeq.Generics" module
    to get started.
    .
    The original idea was pioneered in the @generic-deepseq@ package
    (see <http://www.haskell.org/pipermail/haskell-cafe/2012-February/099551.html>
    for more information).
    .
    This package differs from the @generic-deepseq@ package by working
    in combination with the existing @deepseq@ package as opposed to
    defining a conflicting drop-in replacement for @deepseq@'\''s
    @Control.DeepSeq@ module.
    .
    __Note__: The ability to auto-derive via "GHC.Generics" has been
    merged into @deepseq-1.4.0.0@. This package is now still useful
    for writing code that'\''s also compatible with older @deepseq@
    versions not yet providing "GHC.Generics"-support.
category: Control
abi: 5c4dbc1e4e34ad7aa9c4144ecfdee7ff
exposed: True
exposed-modules:
    Control.DeepSeq.Generics
import-dirs: /usr/lib/ghc-8.6.1/site-local/deepseq-generics-0.2.0.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/deepseq-generics-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/deepseq-generics-0.2.0.0
hs-libraries: HSdeepseq-generics-0.2.0.0-JZY7BpT2g3X1HaqlHiVnph
depends:
    base-4.12.0.0 deepseq-1.4.4.0 ghc-prim-0.5.3
haddock-interfaces: /usr/share/doc/haskell-deepseq-generics/html/deepseq-generics.haddock
haddock-html: /usr/share/doc/haskell-deepseq-generics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
